@@ -20,6 +20,8 @@ from bip_utils.addr import (
     P2PKH, BchP2PKH, P2SH, BchP2SH, P2WPKH,
     AtomAddr,
     AvaxPChainAddr, AvaxXChainAddr,
+    OkexAddr,
+    OneAddr,
     EthAddr,
     TrxAddr,
     XrpAddr
