@@ -4,5 +4,7 @@ from bip_utils.addr.P2WPKH_addr import P2WPKH
 from bip_utils.addr.atom_addr import AtomAddr
 from bip_utils.addr.avax_addr import AvaxPChainAddr, AvaxXChainAddr
 from bip_utils.addr.eth_addr import EthAddr
+from bip_utils.addr.okex_addr import OkexAddr
+from bip_utils.addr.one_addr import OneAddr
 from bip_utils.addr.trx_addr import TrxAddr
 from bip_utils.addr.xrp_addr import XrpAddr
