@@ -59,6 +59,15 @@ class Bip44Coins(Enum):
     AVAX_C_CHAIN = auto(),
     AVAX_X_CHAIN = auto(),
     AVAX_P_CHAIN = auto(),
+    POLYGON = auto(),
+    FANTOM_OPERA = auto(),
+    HARMONY_ONE_METAMASK = auto(),
+    HARMONY_ONE_ETH = auto(),
+    HARMONY_ONE_ATOM = auto(),
+    HUOBI_CHAIN = auto(),
+    OKEX_CHAIN_ETH = auto(),
+    OKEX_CHAIN_ATOM = auto(),
+    OKEX_CHAIN_ATOM_OLD = auto(),
     NINE_CHRONICLES_GOLD = auto(),
     # Test nets
     BITCOIN_TESTNET = auto(),
@@ -103,6 +112,12 @@ class Bip44BaseConst:
             Bip44Coins.ETHEREUM: 60,
             Bip44Coins.BINANCE_SMART_CHAIN: 60,
             Bip44Coins.AVAX_C_CHAIN: 60,
+            Bip44Coins.POLYGON: 60,
+            Bip44Coins.FANTOM_OPERA: 60,
+            Bip44Coins.HUOBI_CHAIN: 60,
+            Bip44Coins.HARMONY_ONE_METAMASK: 60,
+            Bip44Coins.OKEX_CHAIN_ETH: 60,
+            Bip44Coins.OKEX_CHAIN_ATOM: 60,
             Bip44Coins.ETHEREUM_CLASSIC: 61,
             Bip44Coins.COSMOS: 118,
             Bip44Coins.IRIS_NET: 118,
@@ -117,6 +132,9 @@ class Bip44BaseConst:
             Bip44Coins.NINE_CHRONICLES_GOLD: 567,
             Bip44Coins.BINANCE_CHAIN: 714,
             Bip44Coins.VECHAIN: 818,
+            Bip44Coins.OKEX_CHAIN_ATOM_OLD: 996,
+            Bip44Coins.HARMONY_ONE_ETH: 1023,
+            Bip44Coins.HARMONY_ONE_ATOM: 1023,
             Bip44Coins.AVAX_X_CHAIN: 9000,
             Bip44Coins.AVAX_P_CHAIN: 9000,
             # Test nets
