@@ -32,15 +32,15 @@ class Bip49Coin(BipCoinBase):
     def __init__(self,
                  coin_conf: Any,
                  is_testnet: bool,
-                 addr_fct: Any) -> None:
+                 addr_cls: Any) -> None:
         """ Construct class.
 
         Args:
             coin_conf (class): Coin configuration class
             is_testnet (bool): True if test net, false otherwise
-            addr_fct (class) : Address class
+            addr_cls (class) : Address class
         """
-        super().__init__(coin_conf, coin_conf.BIP49_KEY_NET_VER, is_testnet, addr_fct)
+        super().__init__(coin_conf, coin_conf.BIP49_KEY_NET_VER, is_testnet, addr_cls)
 
 
 class Bip49Litecoin(Bip49Coin):
@@ -78,7 +78,7 @@ class Bip49Litecoin(Bip49Coin):
                     if not self.m_coin_conf.P2SH_DEPR_ADDR
                     else self.m_coin_conf.P2SH_DEPR_NET_VER)
         addr_ver = p2sh_ver.Main() if not self.m_is_testnet else p2sh_ver.Test()
-        return self.m_addr_fct.ToAddress(pub_key.RawCompressed().ToBytes(), addr_ver)
+        return self.m_addr_cls.ToAddress(pub_key.RawCompressed().ToBytes(), addr_ver)
 
 
 class Bip49BitcoinCash(Bip49Coin):
@@ -101,88 +101,88 @@ class Bip49BitcoinCash(Bip49Coin):
             addr_ver = (self.m_coin_conf.BCH_P2SH_NET_VER.Main()
                         if not self.m_is_testnet
                         else self.m_coin_conf.BCH_P2SH_NET_VER.Test())
-            return self.m_addr_fct["bch"].ToAddress(pub_key.RawCompressed().ToBytes(), addr_ver["hrp"],
+            return self.m_addr_cls["bch"].ToAddress(pub_key.RawCompressed().ToBytes(), addr_ver["hrp"],
                                                     addr_ver["net_ver"])
         else:
             addr_ver = (self.m_coin_conf.LEGACY_P2SH_NET_VER.Main()
                         if not self.m_is_testnet
                         else self.m_coin_conf.LEGACY_P2SH_NET_VER.Test())
-            return self.m_addr_fct["legacy"].ToAddress(pub_key.RawCompressed().ToBytes(), addr_ver)
+            return self.m_addr_cls["legacy"].ToAddress(pub_key.RawCompressed().ToBytes(), addr_ver)
 
 
 # Configuration for Bitcoin main net
 Bip49BitcoinMainNet: Bip49Coin = Bip49Coin(
     coin_conf=BitcoinConf,
     is_testnet=False,
-    addr_fct=P2SH)
+    addr_cls=P2SH)
 # Configuration for Bitcoin test net
 Bip49BitcoinTestNet: Bip49Coin = Bip49Coin(
     coin_conf=BitcoinConf,
     is_testnet=True,
-    addr_fct=P2SH)
+    addr_cls=P2SH)
 
 # Configuration for Bitcoin Cash main net
 Bip49BitcoinCashMainNet: Bip49BitcoinCash = Bip49BitcoinCash(
     coin_conf=BitcoinCashConf,
     is_testnet=False,
-    addr_fct={"legacy": P2SH, "bch": BchP2SH})
+    addr_cls={"legacy": P2SH, "bch": BchP2SH})
 # Configuration for Bitcoin Cash test net
 Bip49BitcoinCashTestNet: Bip49BitcoinCash = Bip49BitcoinCash(
     coin_conf=BitcoinCashConf,
     is_testnet=True,
-    addr_fct={"legacy": P2SH, "bch": BchP2SH})
+    addr_cls={"legacy": P2SH, "bch": BchP2SH})
 
 # Configuration for BitcoinSV main net
 Bip49BitcoinSvMainNet: Bip49Coin = Bip49Coin(
     coin_conf=BitcoinSvConf,
     is_testnet=False,
-    addr_fct=P2SH)
+    addr_cls=P2SH)
 # Configuration for BitcoinSV test net
 Bip49BitcoinSvTestNet: Bip49Coin = Bip49Coin(
     coin_conf=BitcoinSvConf,
     is_testnet=True,
-    addr_fct=P2SH)
+    addr_cls=P2SH)
 
 # Configuration for Litecoin main net
 Bip49LitecoinMainNet: Bip49Litecoin = Bip49Litecoin(
     coin_conf=LitecoinConf,
     is_testnet=False,
-    addr_fct=P2SH)
+    addr_cls=P2SH)
 # Configuration for Litecoin test net
 Bip49LitecoinTestNet: Bip49Litecoin = Bip49Litecoin(
     coin_conf=LitecoinConf,
     is_testnet=True,
-    addr_fct=P2SH)
+    addr_cls=P2SH)
 
 # Configuration for Dogecoin main net
 Bip49DogecoinMainNet: Bip49Coin = Bip49Coin(
     coin_conf=DogecoinConf,
     is_testnet=False,
-    addr_fct=P2SH)
+    addr_cls=P2SH)
 # Configuration for Dogecoin test net
 Bip49DogecoinTestNet: Bip49Coin = Bip49Coin(
     coin_conf=DogecoinConf,
     is_testnet=True,
-    addr_fct=P2SH)
+    addr_cls=P2SH)
 
 # Configuration for Dash main net
 Bip49DashMainNet: Bip49Coin = Bip49Coin(
     coin_conf=DashConf,
     is_testnet=False,
-    addr_fct=P2SH)
+    addr_cls=P2SH)
 # Configuration for Dash test net
 Bip49DashTestNet: Bip49Coin = Bip49Coin(
     coin_conf=DashConf,
     is_testnet=True,
-    addr_fct=P2SH)
+    addr_cls=P2SH)
 
 # Configuration for Zcash main net
 Bip49ZcashMainNet: Bip49Coin = Bip49Coin(
     coin_conf=ZcashConf,
     is_testnet=False,
-    addr_fct=P2SH)
+    addr_cls=P2SH)
 # Configuration for Zcash test net
 Bip49ZcashTestNet: Bip49Coin = Bip49Coin(
     coin_conf=ZcashConf,
     is_testnet=True,
-    addr_fct=P2SH)
+    addr_cls=P2SH)
