@@ -31,35 +31,35 @@ class Bip84Coin(BipCoinBase):
     def __init__(self,
                  coin_conf: Any,
                  is_testnet: bool,
-                 addr_fct: Any) -> None:
+                 addr_cls: Any) -> None:
         """ Construct class.
 
         Args:
             coin_conf (class): Coin configuration class
             is_testnet (bool): True if test net, false otherwise
-            addr_fct (class) : Address class
+            addr_cls (class) : Address class
         """
-        super().__init__(coin_conf, coin_conf.BIP84_KEY_NET_VER, is_testnet, addr_fct)
+        super().__init__(coin_conf, coin_conf.BIP84_KEY_NET_VER, is_testnet, addr_cls)
 
 
 # Configuration for Bitcoin main net
 Bip84BitcoinMainNet: Bip84Coin = Bip84Coin(
     coin_conf=BitcoinConf,
     is_testnet=False,
-    addr_fct=P2WPKH)
+    addr_cls=P2WPKH)
 # Configuration for Bitcoin test net
 Bip84BitcoinTestNet: Bip84Coin = Bip84Coin(
     coin_conf=BitcoinConf,
     is_testnet=True,
-    addr_fct=P2WPKH)
+    addr_cls=P2WPKH)
 
 # Configuration for Litecoin main net
 Bip84LitecoinMainNet: Bip84Coin = Bip84Coin(
     coin_conf=LitecoinConf,
     is_testnet=False,
-    addr_fct=P2WPKH)
+    addr_cls=P2WPKH)
 # Configuration for Litecoin test net
 Bip84LitecoinTestNet: Bip84Coin = Bip84Coin(
     coin_conf=LitecoinConf,
     is_testnet=True,
-    addr_fct=P2WPKH)
+    addr_cls=P2WPKH)
